
import json
import unittest

import ggps


class PathHandlerTest(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_str(self):
        handler = ggps.PathHandler()
        actual = str(handler)
        expected = '{}'
        msg = "Should be {0}, got {1}".format(expected, actual)
        self.assertTrue(actual == expected, msg)

        filename = 'data/twin_cities_marathon.gpx'
        handler = ggps.PathHandler.parse(filename)
        obj = json.loads(str(handler))
        cnt = obj['gpx|trk|trkseg|trkpt@lat']
        msg = "count of 2256 expected at 'gpx|trk|trkseg|trkpt@lat'"
        self.assertTrue(cnt == 2256, msg)

    def test_counts(self):
        filename = 'data/twin_cities_marathon.gpx'
        handler = ggps.PathHandler.parse(filename)
        counter = handler.path_counter

        cnt = counter['gpx|trk|trkseg|trkpt@lat']
        msg = "count of 2256 expected at 'gpx|trk|trkseg|trkpt@lat'"
        self.assertTrue(cnt == 2256, msg)

        cnt = counter['gpx|metadata|time']
        msg = "count of 1 expected at 'gpx|metadata|time'"
        self.assertTrue(cnt == 1, msg)

    def test_base_parse_hhmmss(self):
        filename = 'data/twin_cities_marathon.gpx'
        handler = ggps.PathHandler.parse(filename)

        hhmmss = handler.parse_hhmmss('')
        self.assertTrue(hhmmss == '', 'an empty hhmmss str was expected')

        hhmmss = handler.parse_hhmmss('xxx')
        self.assertTrue(hhmmss == '', 'an empty hhmmss str was expected')



import unittest

import ggps


class GpxHandlerTest(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def expected_first_trackpoint(self):
        return {
            "elapsedtime": "00:00:00",
            "heartratebpm": "85",
            "latitudedegrees": "44.97431952506304",
            "longitudedegrees": "-93.26310088858008",
            "seq": "1",
            "time": "2014-10-05T13:07:53.000Z",
            "type": "Trackpoint"
        }

    def expected_middle_trackpoint(self):
        return {
            "elapsedtime": "03:13:19",
            "heartratebpm": "140",
            "latitudedegrees": "44.959017438814044",
            "longitudedegrees": "-93.21290854364634",
            "seq": "1747",
            "time": "2014-10-05T16:21:12.000Z",
            "type": "Trackpoint"
        }

    def expected_last_trackpoint(self):
        return {
            "elapsedtime": "04:14:24",
            "heartratebpm": "161",
            "latitudedegrees": "44.95180849917233",
            "longitudedegrees": "-93.10493202880025",
            "seq": "2256",
            "time": "2014-10-05T17:22:17.000Z",
            "type": "Trackpoint"
        }

    def test_twin_cities_marathon_gpx_file(self):
        filename = 'data/twin_cities_marathon.gpx'
        handler = ggps.GpxHandler.parse(filename)

        tkpts = handler.trackpoints
        expected_attr_count = 7

        # check the number of trackpoints
        actual = len(tkpts)
        expected = 2256
        msg = "Should be {0} trackpoints, got {1}".format(expected, actual)
        self.assertTrue(actual == expected, msg)

        # check the first trackpoint
        expected_tkpt = self.expected_first_trackpoint()
        actual_tkpt = handler.trackpoints[0]
        self.assertTrue(len(actual_tkpt.values) == expected_attr_count)
        for key in expected_tkpt.keys():
            expected, actual = expected_tkpt[key], actual_tkpt.values[key]
            self.assertTrue(expected == actual, "first tkpt, key {0}".format(key))

        # check a trackpoint at ~mile 20
        expected_tkpt = self.expected_middle_trackpoint()
        actual_tkpt = handler.trackpoints[1746]
        self.assertTrue(len(actual_tkpt.values) == expected_attr_count)
        for key in expected_tkpt.keys():
            expected, actual = expected_tkpt[key], actual_tkpt.values[key]
            self.assertTrue(expected == actual, "20m tkpt, key {0}".format(key))

        # check the last trackpoint
        expected_tkpt = self.expected_last_trackpoint()
        actual_tkpt = handler.trackpoints[-1]
        self.assertTrue(len(actual_tkpt.values) == expected_attr_count)
        for key in expected_tkpt.keys():
            expected, actual = expected_tkpt[key], actual_tkpt.values[key]
            self.assertTrue(expected == actual, "last tkpt, key {0}".format(key))

        # check seconds_to_midnight
        secs = int(handler.first_time_secs_to_midnight)
        self.assertTrue(secs > 0, "first_time_secs_to_midnight is too small")
        self.assertTrue(secs < 86400, "first_time_secs_to_midnight is too large")




import json
import unittest

import ggps


class TrackpointTest(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_str(self):
        t = ggps.Trackpoint()
        actual = str(t)
        expected = '<Trackpoint values count:1>'
        msg = "Should be {0}, got {1}".format(expected, actual)
        self.assertTrue(actual == expected, msg)

    def test_repr(self):
        t = ggps.Trackpoint()
        t.set('lang', 'python')
        t.set(None, 'python')
        j = repr(t)
        obj = json.loads(j)
        t = obj['type']
        l = obj['lang']
        self.assertTrue(t == 'Trackpoint', "expected the value 'Trackpoint'")
        self.assertTrue(l == 'python', "expected the value 'python'")

    def test_get(self):
        t = ggps.Trackpoint()
        t.set('lang', 'python')
        l = t.get('lang')
        x = t.get('xxx')
        z = t.get('zzz', 'zero')
        self.assertTrue(l == 'python', "expected the value 'python'")
        self.assertTrue(x == '', "expected the value ''")
        self.assertTrue(z == 'zero', "expected the value 'zero'")



__author__ = 'cjoakim'
__version__ = '0.1.4'

VERSION = __version__

"""
ggps library
"""

from .trackpoint import Trackpoint
from .base_handler import BaseHandler
from .gpx_handler import GpxHandler
from .tcx_handler import TcxHandler
from .path_handler import PathHandler